#include "interface_-client.h"
#include "interface_-server.h"


static const CORBA::Long _oc_long10[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    15, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x6c6f6e67), ACE_NTOHL(0x31303a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:long10:1.0 */,
    7, ACE_NTOHL(0x6c6f6e67), ACE_NTOHL(0x31300000) /* name = long10 */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      10
};

static CORBA::TypeCode _tc_TAO_tc_long10 (CORBA::tk_alias, sizeof(_oc_long10), (char *) &_oc_long10, 0, sizeof(long10 ));

CORBA::TypeCode_ptr _tc_long10 = &_tc_TAO_tc_long10;


long10::long10()
  : _maximum(10),
    _length(0),
    _buffer(long10::allocbuf(10)),
    _release(1)
{
}

long10::long10(CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(10),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

long10::long10(const long10 &o)
  : _maximum(10),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = long10::allocbuf(this->_maximum);

  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

long10::~long10()
{
  this->_deallocate_buffer();
}

long10 &long10::operator=(const long10 &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  

  }
  else
    this->_buffer = long10::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Long &long10::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &long10::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *long10::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void long10::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void long10::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = long10::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      long10::freebuf(old);
  }
  this->_buffer = tmp;
}

void long10::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);


  long10::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean long10::release() const
{
  return this->_release;
}

CORBA::ULong long10::maximum() const
{
  return 10;
}

CORBA::ULong long10::length() const
{
  return this->_length;
}

void long10::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void long10::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Long *long10::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = long10::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *long10::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const long10 &o)
{
  long10  *_any_val;
  ACE_NEW(_any_val, long10  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_long10, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, long10 *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_long10, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, long10 *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_long10, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (long10  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, long10 , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_long10, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_long10, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

long10_var::long10_var()
  : ptr_(0)
{}

long10_var::long10_var(long10 *p)
 : ptr_(p)
{}

long10_var::long10_var(const long10_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new long10 (*a.ptr_);
  else
    this->ptr_ = 0;
}

long10_var::~long10_var()
{
  delete this->ptr_;
}

long10_var &long10_var::operator=(long10 *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

long10_var &long10_var::operator=(const long10_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new long10 (*p.ptr_);
  }
  return *this;
}

CORBA::Long &long10_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &long10_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

long10 *long10_var::operator->()
{
  return this->ptr_;
}

const long10 *long10_var::operator->() const
{
  return this->ptr_;
}

long10_var::operator const long10 &() const
{
  return *this->ptr_;
}

long10_var::operator long10 &()
{
  return *this->ptr_;
}

long10_var::operator long10 &() const
{
  return *this->ptr_;
}

const long10 &long10_var::in() const
{
  return *this->ptr_;
}

long10 &long10_var::inout()
{
  return *this->ptr_;
}

long10 *&long10_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

long10 *long10_var::_retn()
{
  long10  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

long10 *long10_var::ptr() const
{
  return this->ptr_;
}

long10_out::long10_out(long10 *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

long10_out::long10_out(long10_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

long10_out::long10_out(const long10_out &r)
  : ptr_(ACE_const_cast(long10_out &,r).ptr_)
{}

long10_out &long10_out::operator=(const long10_out &r)
{
  this->ptr_ = ACE_const_cast(long10_out &,r).ptr_;
  return *this;
}

long10_out &long10_out::operator=(long10 *r)
{
  this->ptr_ = r;
  return *this;
}

long10_out::operator long10 *&()
{
  return this->ptr_;
}

long10 *&long10_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &long10_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &long10_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

long10 *long10_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_math[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    13, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x6d617468), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:math:1.0 */,
    5, ACE_NTOHL(0x6d617468), ACE_NTOHL(0x00000000) /* name = math */
};

static CORBA::TypeCode _tc_TAO_tc_math (CORBA::tk_objref, sizeof(_oc_math), (char *) &_oc_math, 0, sizeof(math ));

CORBA::TypeCode_ptr _tc_math = &_tc_TAO_tc_math;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<math , math_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<math , math_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


math_ptr  (*_TAO_collocation_math_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


math_ptr math::_duplicate(math_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

math_ptr math::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return math::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:math:1.0", _env);
  if (_env.exception() != 0)
    return math::_nil();
  if (is_a == 0)
    return math::_nil();
  return math::_unchecked_narrow(obj, _env);
}

math_ptr math::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return math::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_math_Stub_Factory_function_pointer != 0)
    {
      math_ptr  retv = _TAO_collocation_math_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new math (stub);
}

math_ptr math::_nil()
{
  return (math_ptr )NULL;
}

CORBA::Boolean math::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:math:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *math::_interface_repository_id() const
{
  return "IDL:math:1.0";
}

math::math()
{}

math::~math()
{}

void operator<<=(CORBA::Any &a, math_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = math::_duplicate(o);
    a.replace (_tc_math, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, math_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = math::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_math, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_math, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = math::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_math, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

math::math(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

math_var::math_var()
  : ptr_(math::_nil())
{}

math_var::math_var(math_ptr p)
  : ptr_(p)
{}

math_var::math_var(const math_var &a)
  : ptr_(math::_duplicate(a.ptr()))
{}

math_var::~math_var()
{
  CORBA::release(this->ptr_);
}

math_var &math_var::operator=(math_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

math_var &math_var::operator=(const math_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = math::_duplicate(p.ptr());
  }
  return *this;
}

math_ptr math_var::operator->() const
{
  return this->ptr_;
}

math_var::operator const math_ptr &() const
{
  return this->ptr_;
}

math_var::operator math_ptr &()
{
  return this->ptr_;
}

math_ptr math_var::in() const
{
  return this->ptr_;
}

math_ptr &math_var::inout()
{
  return this->ptr_;
}

math_ptr &math_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = math::_nil();
  return this->ptr_;
}

math_ptr math_var::_retn()
{
  math_ptr  val = this->ptr_;
  this->ptr_ = math::_nil();
  return val;
}

math_ptr math_var::ptr() const
{
  return this->ptr_;
}

math_out::math_out(math_ptr &r)
  : ptr_(r)
{
  this->ptr_ = math::_nil();
}

math_out::math_out(math_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = math::_nil();
}

math_out::math_out(const math_out &r)
  : ptr_(ACE_const_cast(math_out &,r).ptr_)
{}

math_out &math_out::operator=(const math_out &r)
{
  this->ptr_ = ACE_const_cast(math_out &,r).ptr_;
  return *this;
}

math_out &math_out::operator=(const math_var &r)
{
  this->ptr_ = math::_duplicate(r.ptr());
  return *this;
}

math_out &math_out::operator=(math_ptr r)
{
  this->ptr_ = r;
  return *this;
}

math_out::operator math_ptr &()
{
  return this->ptr_;
}

math_ptr &math_out::ptr()
{
  return this->ptr_;
}

math_ptr math_out::operator->()
{
  return this->ptr_;
}
CORBA::Short math::addshort(/* math *this, */ CORBA::Short a, CORBA::Short b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Short _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort1);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'a', flick_char8_t );
      flick_cdr_encode_char8(5, 'd', flick_char8_t );
      flick_cdr_encode_char8(6, 'd', flick_char8_t );
      flick_cdr_encode_char8(7, 's', flick_char8_t );
      flick_cdr_encode_char8(8, 'h', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed16(20, a, CORBA::Short );
      flick_cdr_encode_signed16(22, b, CORBA::Short );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort14);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_swap_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort14:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort15);
              break;
              {
              _flick_abort15:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort16);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort16:
                goto _flick_abort1;
              }
            }
          }
      }

    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort7);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort7:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort8);
              break;
              {
              _flick_abort8:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort9);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort9:
                goto _flick_abort1;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort1);
  }
  return _return;
  {
  _flick_abort1:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort0);
  _flick_abort0:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Short math::subshort(/* math *this, */ CORBA::Short a, CORBA::Short b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Short _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort18);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort18);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 's', flick_char8_t );
      flick_cdr_encode_char8(5, 'u', flick_char8_t );
      flick_cdr_encode_char8(6, 'b', flick_char8_t );
      flick_cdr_encode_char8(7, 's', flick_char8_t );
      flick_cdr_encode_char8(8, 'h', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed16(20, a, CORBA::Short );
      flick_cdr_encode_signed16(22, b, CORBA::Short );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t3_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t3_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t3_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort31);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_swap_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort31:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort32);
              break;
              {
              _flick_abort32:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort33);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort33:
                goto _flick_abort18;
              }
            }
          }
      }

    else
      {
        int _t2_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t2_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t2_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort24);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort24:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort25);
              break;
              {
              _flick_abort25:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort26);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort26:
                goto _flick_abort18;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort18);
  }
  return _return;
  {
  _flick_abort18:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort17);
  _flick_abort17:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Short math::multshort(/* math *this, */ CORBA::Short a, CORBA::Short b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Short _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort35);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort35);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'm', flick_char8_t );
      flick_cdr_encode_char8(5, 'u', flick_char8_t );
      flick_cdr_encode_char8(6, 'l', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, 's', flick_char8_t );
      flick_cdr_encode_char8(9, 'h', flick_char8_t );
      flick_cdr_encode_char8(10, 'o', flick_char8_t );
      flick_cdr_encode_char8(11, 'r', flick_char8_t );
      flick_cdr_encode_char8(12, 't', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed16(20, a, CORBA::Short );
      flick_cdr_encode_signed16(22, b, CORBA::Short );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t5_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort35);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t5_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t5_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort48);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_swap_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort48:
                goto _flick_abort35;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort49);
              break;
              {
              _flick_abort49:
                goto _flick_abort35;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort50);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort50:
                goto _flick_abort35;
              }
            }
          }
      }

    else
      {
        int _t4_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(6);
        flick_iiopxx_check_span(4, _flick_abort35);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t4_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t4_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(2, _flick_abort41);
              flick_iiopxx_decode_new_chunk(2);
              flick_cdr_decode_signed16(0, _return, CORBA::Short );
              flick_iiopxx_decode_end_chunk(2);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort41:
                goto _flick_abort35;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(6);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort42);
              break;
              {
              _flick_abort42:
                goto _flick_abort35;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort43);
              flick_iiopxx_decode_end_glob(6);
              break;
              {
              _flick_abort43:
                goto _flick_abort35;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort35);
  }
  return _return;
  {
  _flick_abort35:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort34);
  _flick_abort34:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long math::addlong(/* math *this, */ CORBA::Long a, CORBA::Long b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort52);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort52);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'a', flick_char8_t );
      flick_cdr_encode_char8(5, 'd', flick_char8_t );
      flick_cdr_encode_char8(6, 'd', flick_char8_t );
      flick_cdr_encode_char8(7, 'l', flick_char8_t );
      flick_cdr_encode_char8(8, 'o', flick_char8_t );
      flick_cdr_encode_char8(9, 'n', flick_char8_t );
      flick_cdr_encode_char8(10, 'g', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(16, a, CORBA::Long );
      flick_cdr_encode_signed32(20, b, CORBA::Long );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t7_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort52);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t7_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t7_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort65);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort65:
                goto _flick_abort52;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort66);
              break;
              {
              _flick_abort66:
                goto _flick_abort52;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort67);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort67:
                goto _flick_abort52;
              }
            }
          }
      }

    else
      {
        int _t6_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort52);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t6_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t6_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort58);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort58:
                goto _flick_abort52;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort59);
              break;
              {
              _flick_abort59:
                goto _flick_abort52;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort60);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort60:
                goto _flick_abort52;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort52);
  }
  return _return;
  {
  _flick_abort52:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort51);
  _flick_abort51:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long math::sublong(/* math *this, */ CORBA::Long a, CORBA::Long b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort69);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort69);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 's', flick_char8_t );
      flick_cdr_encode_char8(5, 'u', flick_char8_t );
      flick_cdr_encode_char8(6, 'b', flick_char8_t );
      flick_cdr_encode_char8(7, 'l', flick_char8_t );
      flick_cdr_encode_char8(8, 'o', flick_char8_t );
      flick_cdr_encode_char8(9, 'n', flick_char8_t );
      flick_cdr_encode_char8(10, 'g', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(16, a, CORBA::Long );
      flick_cdr_encode_signed32(20, b, CORBA::Long );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort69);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t9_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort69);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t9_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t9_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort82);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort82:
                goto _flick_abort69;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort83);
              break;
              {
              _flick_abort83:
                goto _flick_abort69;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort84);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort84:
                goto _flick_abort69;
              }
            }
          }
      }

    else
      {
        int _t8_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort69);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t8_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t8_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort75);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort75:
                goto _flick_abort69;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort76);
              break;
              {
              _flick_abort76:
                goto _flick_abort69;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort77);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort77:
                goto _flick_abort69;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort69);
  }
  return _return;
  {
  _flick_abort69:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort68);
  _flick_abort68:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long math::multlong(/* math *this, */ CORBA::Long a, CORBA::Long b, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort86);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort86);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'm', flick_char8_t );
      flick_cdr_encode_char8(5, 'u', flick_char8_t );
      flick_cdr_encode_char8(6, 'l', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, 'l', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(20, a, CORBA::Long );
      flick_cdr_encode_signed32(24, b, CORBA::Long );
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort86);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t11_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort86);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t11_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t11_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort99);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort99:
                goto _flick_abort86;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort100);
              break;
              {
              _flick_abort100:
                goto _flick_abort86;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort101);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort101:
                goto _flick_abort86;
              }
            }
          }
      }

    else
      {
        int _t10_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort86);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t10_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t10_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort92);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort92:
                goto _flick_abort86;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort93);
              break;
              {
              _flick_abort93:
                goto _flick_abort86;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort94);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort94:
                goto _flick_abort86;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort86);
  }
  return _return;
  {
  _flick_abort86:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort85);
  _flick_abort85:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long math::addlonglist(/* math *this, */ const long10 &a, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort103);
    }




    {
      flick_iiopxx_encode_new_glob(64, _flick_abort103);
      flick_iiopxx_encode_new_chunk(24 + 4 * a._length);
      flick_cdr_encode_unsigned32(0, 12, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'a', flick_char8_t );
      flick_cdr_encode_char8(5, 'd', flick_char8_t );
      flick_cdr_encode_char8(6, 'd', flick_char8_t );
      flick_cdr_encode_char8(7, 'l', flick_char8_t );
      flick_cdr_encode_char8(8, 'o', flick_char8_t );
      flick_cdr_encode_char8(9, 'n', flick_char8_t );
      flick_cdr_encode_char8(10, 'g', flick_char8_t );
      flick_cdr_encode_char8(11, 'l', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 's', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, a._length, CORBA::ULong );
      if (a._length > 10)
        flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort103);
      flick_cdr_encode_bcopy(24, a._buffer, 4 * a._length);
      flick_iiopxx_encode_end_chunk(24 + 4 * a._length);
      flick_iiopxx_encode_end_glob(64);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort103);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t13_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort103);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t13_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t13_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort120);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort120:
                goto _flick_abort103;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort121);
              break;
              {
              _flick_abort121:
                goto _flick_abort103;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort122);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort122:
                goto _flick_abort103;
              }
            }
          }
      }

    else
      {
        int _t12_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort103);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t12_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t12_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort113);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort113:
                goto _flick_abort103;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort114);
              break;
              {
              _flick_abort114:
                goto _flick_abort103;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort115);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort115:
                goto _flick_abort103;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort103);
  }
  return _return;
  {
  _flick_abort103:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort102);
  _flick_abort102:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long math::multlonglist(/* math *this, */ const long10 &a, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort124);
    }




    {
      flick_iiopxx_encode_new_glob(68, _flick_abort124);
      flick_iiopxx_encode_new_chunk(28 + 4 * a._length);
      flick_cdr_encode_unsigned32(0, 13, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'm', flick_char8_t );
      flick_cdr_encode_char8(5, 'u', flick_char8_t );
      flick_cdr_encode_char8(6, 'l', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, 'l', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 'l', flick_char8_t );
      flick_cdr_encode_char8(13, 'i', flick_char8_t );
      flick_cdr_encode_char8(14, 's', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(24, a._length, CORBA::ULong );
      if (a._length > 10)
        flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort124);
      flick_cdr_encode_bcopy(28, a._buffer, 4 * a._length);
      flick_iiopxx_encode_end_chunk(28 + 4 * a._length);
      flick_iiopxx_encode_end_glob(68);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort124);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t15_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort124);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t15_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t15_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort141);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort141:
                goto _flick_abort124;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort142);
              break;
              {
              _flick_abort142:
                goto _flick_abort124;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort143);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort143:
                goto _flick_abort124;
              }
            }
          }
      }

    else
      {
        int _t14_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort124);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t14_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t14_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort134);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort134:
                goto _flick_abort124;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort135);
              break;
              {
              _flick_abort135:
                goto _flick_abort124;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort136);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort136:
                goto _flick_abort124;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort124);
  }
  return _return;
  {
  _flick_abort124:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort123);
  _flick_abort123:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

