#include "sequence_-client.h"
#include "sequence_-server.h"


static const CORBA::Long _oc_seq[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    12, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x7365713a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:seq:1.0 */,
    4, ACE_NTOHL(0x73657100) /* name = seq */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      10
};

static CORBA::TypeCode _tc_TAO_tc_seq (CORBA::tk_alias, sizeof(_oc_seq), (char *) &_oc_seq, 0, sizeof(seq ));

CORBA::TypeCode_ptr _tc_seq = &_tc_TAO_tc_seq;


seq::seq()
  : _maximum(10),
    _length(0),
    _buffer(seq::allocbuf(10)),
    _release(1)
{
}

seq::seq(CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(10),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

seq::seq(const seq &o)
  : _maximum(10),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = seq::allocbuf(this->_maximum);

  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

seq::~seq()
{
  this->_deallocate_buffer();
}

seq &seq::operator=(const seq &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  

  }
  else
    this->_buffer = seq::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Long &seq::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &seq::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *seq::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void seq::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void seq::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = seq::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      seq::freebuf(old);
  }
  this->_buffer = tmp;
}

void seq::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);


  seq::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean seq::release() const
{
  return this->_release;
}

CORBA::ULong seq::maximum() const
{
  return 10;
}

CORBA::ULong seq::length() const
{
  return this->_length;
}

void seq::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void seq::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Long *seq::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = seq::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *seq::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const seq &o)
{
  seq  *_any_val;
  ACE_NEW(_any_val, seq  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_seq, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, seq *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_seq, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, seq *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_seq, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (seq  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, seq , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_seq, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_seq, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

seq_var::seq_var()
  : ptr_(0)
{}

seq_var::seq_var(seq *p)
 : ptr_(p)
{}

seq_var::seq_var(const seq_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new seq (*a.ptr_);
  else
    this->ptr_ = 0;
}

seq_var::~seq_var()
{
  delete this->ptr_;
}

seq_var &seq_var::operator=(seq *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

seq_var &seq_var::operator=(const seq_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new seq (*p.ptr_);
  }
  return *this;
}

CORBA::Long &seq_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &seq_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

seq *seq_var::operator->()
{
  return this->ptr_;
}

const seq *seq_var::operator->() const
{
  return this->ptr_;
}

seq_var::operator const seq &() const
{
  return *this->ptr_;
}

seq_var::operator seq &()
{
  return *this->ptr_;
}

seq_var::operator seq &() const
{
  return *this->ptr_;
}

const seq &seq_var::in() const
{
  return *this->ptr_;
}

seq &seq_var::inout()
{
  return *this->ptr_;
}

seq *&seq_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

seq *seq_var::_retn()
{
  seq  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

seq *seq_var::ptr() const
{
  return this->ptr_;
}

seq_out::seq_out(seq *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

seq_out::seq_out(seq_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

seq_out::seq_out(const seq_out &r)
  : ptr_(ACE_const_cast(seq_out &,r).ptr_)
{}

seq_out &seq_out::operator=(const seq_out &r)
{
  this->ptr_ = ACE_const_cast(seq_out &,r).ptr_;
  return *this;
}

seq_out &seq_out::operator=(seq *r)
{
  this->ptr_ = r;
  return *this;
}

seq_out::operator seq *&()
{
  return this->ptr_;
}

seq *&seq_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &seq_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &seq_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

seq *seq_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_TestSeq[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x54657374), ACE_NTOHL(0x5365713a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:TestSeq:1.0 */,
    8, ACE_NTOHL(0x54657374), ACE_NTOHL(0x53657100) /* name = TestSeq */
};

static CORBA::TypeCode _tc_TAO_tc_TestSeq (CORBA::tk_objref, sizeof(_oc_TestSeq), (char *) &_oc_TestSeq, 0, sizeof(TestSeq ));

CORBA::TypeCode_ptr _tc_TestSeq = &_tc_TAO_tc_TestSeq;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<TestSeq , TestSeq_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<TestSeq , TestSeq_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


TestSeq_ptr  (*_TAO_collocation_TestSeq_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


TestSeq_ptr TestSeq::_duplicate(TestSeq_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

TestSeq_ptr TestSeq::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return TestSeq::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:TestSeq:1.0", _env);
  if (_env.exception() != 0)
    return TestSeq::_nil();
  if (is_a == 0)
    return TestSeq::_nil();
  return TestSeq::_unchecked_narrow(obj, _env);
}

TestSeq_ptr TestSeq::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return TestSeq::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_TestSeq_Stub_Factory_function_pointer != 0)
    {
      TestSeq_ptr  retv = _TAO_collocation_TestSeq_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new TestSeq (stub);
}

TestSeq_ptr TestSeq::_nil()
{
  return (TestSeq_ptr )NULL;
}

CORBA::Boolean TestSeq::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:TestSeq:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *TestSeq::_interface_repository_id() const
{
  return "IDL:TestSeq:1.0";
}

TestSeq::TestSeq()
{}

TestSeq::~TestSeq()
{}

void operator<<=(CORBA::Any &a, TestSeq_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = TestSeq::_duplicate(o);
    a.replace (_tc_TestSeq, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, TestSeq_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = TestSeq::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_TestSeq, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_TestSeq, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = TestSeq::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_TestSeq, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

TestSeq::TestSeq(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

TestSeq_var::TestSeq_var()
  : ptr_(TestSeq::_nil())
{}

TestSeq_var::TestSeq_var(TestSeq_ptr p)
  : ptr_(p)
{}

TestSeq_var::TestSeq_var(const TestSeq_var &a)
  : ptr_(TestSeq::_duplicate(a.ptr()))
{}

TestSeq_var::~TestSeq_var()
{
  CORBA::release(this->ptr_);
}

TestSeq_var &TestSeq_var::operator=(TestSeq_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

TestSeq_var &TestSeq_var::operator=(const TestSeq_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = TestSeq::_duplicate(p.ptr());
  }
  return *this;
}

TestSeq_ptr TestSeq_var::operator->() const
{
  return this->ptr_;
}

TestSeq_var::operator const TestSeq_ptr &() const
{
  return this->ptr_;
}

TestSeq_var::operator TestSeq_ptr &()
{
  return this->ptr_;
}

TestSeq_ptr TestSeq_var::in() const
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_var::inout()
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = TestSeq::_nil();
  return this->ptr_;
}

TestSeq_ptr TestSeq_var::_retn()
{
  TestSeq_ptr  val = this->ptr_;
  this->ptr_ = TestSeq::_nil();
  return val;
}

TestSeq_ptr TestSeq_var::ptr() const
{
  return this->ptr_;
}

TestSeq_out::TestSeq_out(TestSeq_ptr &r)
  : ptr_(r)
{
  this->ptr_ = TestSeq::_nil();
}

TestSeq_out::TestSeq_out(TestSeq_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = TestSeq::_nil();
}

TestSeq_out::TestSeq_out(const TestSeq_out &r)
  : ptr_(ACE_const_cast(TestSeq_out &,r).ptr_)
{}

TestSeq_out &TestSeq_out::operator=(const TestSeq_out &r)
{
  this->ptr_ = ACE_const_cast(TestSeq_out &,r).ptr_;
  return *this;
}

TestSeq_out &TestSeq_out::operator=(const TestSeq_var &r)
{
  this->ptr_ = TestSeq::_duplicate(r.ptr());
  return *this;
}

TestSeq_out &TestSeq_out::operator=(TestSeq_ptr r)
{
  this->ptr_ = r;
  return *this;
}

TestSeq_out::operator TestSeq_ptr &()
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_out::ptr()
{
  return this->ptr_;
}

TestSeq_ptr TestSeq_out::operator->()
{
  return this->ptr_;
}
CORBA::Short TestSeq::Sequencer(/* TestSeq *this, */ seq &a, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Short _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1);
    }




    {
      flick_iiopxx_encode_new_glob(64, _flick_abort1);
      flick_iiopxx_encode_new_chunk(24 + 4 * a._length);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'S', flick_char8_t );
      flick_cdr_encode_char8(5, 'e', flick_char8_t );
      flick_cdr_encode_char8(6, 'q', flick_char8_t );
      flick_cdr_encode_char8(7, 'u', flick_char8_t );
      flick_cdr_encode_char8(8, 'e', flick_char8_t );
      flick_cdr_encode_char8(9, 'n', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 'e', flick_char8_t );
      flick_cdr_encode_char8(12, 'r', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, a._length, CORBA::ULong );
      if (a._length > 10)
        flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort1);
      flick_cdr_encode_bcopy(24, a._buffer, 4 * a._length);
      flick_iiopxx_encode_end_chunk(24 + 4 * a._length);
      flick_iiopxx_encode_end_glob(64);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(52);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t3_array_iter;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort27);
              flick_iiopxx_decode_new_chunk(8);
              flick_cdr_swap_decode_signed16(0, _return, CORBA::Short );
              flick_cdr_swap_decode_unsigned32(4, a._length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(8);
              if (a._length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort27);
              flick_iiopxx_check_span(a._length * 4, _flick_abort27);
              for (_t3_array_iter = 0; _t3_array_iter < a._length; _t3_array_iter++)
                {
                  flick_iiopxx_decode_new_chunk(4);
                  flick_cdr_swap_decode_signed32(0, a._buffer[_t3_array_iter], CORBA::Long );
                  flick_iiopxx_decode_end_chunk(4);
                  continue;
                }
              flick_iiopxx_decode_end_glob(52);
              break;
              {
              _flick_abort27:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(52);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort33);
              break;
              {
              _flick_abort33:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort34);
              flick_iiopxx_decode_end_glob(52);
              break;
              {
              _flick_abort34:
                goto _flick_abort1;
              }
            }
          }
      }

    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(52);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort13);
              flick_iiopxx_decode_new_chunk(8);
              flick_cdr_decode_signed16(0, _return, CORBA::Short );
              flick_cdr_decode_unsigned32(4, a._length, CORBA::ULong );
              if (a._length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort13);
              flick_iiopxx_decode_end_chunk(8);
              flick_iiopxx_check_span(4 * a._length, _flick_abort13);
              flick_iiopxx_decode_new_chunk(4 * a._length);
              flick_cdr_decode_bcopy(0, a._buffer, 4 * a._length);
              flick_iiopxx_decode_end_chunk(4 * a._length);
              flick_iiopxx_decode_end_glob(52);
              break;
              {
              _flick_abort13:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(52);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort16);
              break;
              {
              _flick_abort16:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort17);
              flick_iiopxx_decode_end_glob(52);
              break;
              {
              _flick_abort17:
                goto _flick_abort1;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort1);
  }
  return _return;
  {
  _flick_abort1:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort0);
  _flick_abort0:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

