#include "impldef-client.h"
#include "impldef-server.h"


static const CORBA::Long _oc_CORBA_StringSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    29, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f5374), ACE_NTOHL(0x72696e67), ACE_NTOHL(0x53657175), ACE_NTOHL(0x656e6365), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:CORBA/StringSequence:1.0 */,
    15, ACE_NTOHL(0x53747269), ACE_NTOHL(0x6e675365), ACE_NTOHL(0x7175656e), ACE_NTOHL(0x63650000) /* name = StringSequence */,
    CORBA::tk_sequence,
    16 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_string,
      0,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_StringSequence (CORBA::tk_alias, sizeof(_oc_CORBA_StringSequence), (char *) &_oc_CORBA_StringSequence, 0, sizeof(::CORBA::StringSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_StringSequence, &_tc_TAO_tc_CORBA_StringSequence)
TAO_NAMESPACE_END

CORBA::StringSequence::StringSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::StringSequence::StringSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::StringSequence::allocbuf(this->_maximum);
}

CORBA::StringSequence::StringSequence(CORBA::ULong max, CORBA::ULong length, char **buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::StringSequence::StringSequence(const ::CORBA::StringSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  char * *tmp1 = CORBA::StringSequence::allocbuf(this->_maximum);

  char * * const tmp2 = ACE_reinterpret_cast(char * * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = CORBA::string_dup(tmp2[i]);

  this->_buffer = tmp1;
}

CORBA::StringSequence::~StringSequence()
{
  this->_deallocate_buffer();
}

::CORBA::StringSequence &CORBA::StringSequence::operator=(const ::CORBA::StringSequence &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);

      for(CORBA::ULong i = 0; i < this->_length; i++)
      {
        CORBA::string_free(tmp[i]);
        tmp[i] = (char *)0;
      }
      
      CORBA::StringSequence::freebuf(tmp);
      this->_buffer = CORBA::StringSequence::allocbuf(rhs._maximum);
    }

  }
  else
    this->_buffer = CORBA::StringSequence::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  char * *tmp1 = ACE_reinterpret_cast(char * *, this->_buffer);
  char * * const tmp2 = ACE_reinterpret_cast(char * * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = CORBA::string_dup(tmp2[i]);

  return *this;
}

char **CORBA::StringSequence::allocbuf(CORBA::ULong size)
{
  char **buf = new char *[size];
  for(CORBA::ULong i=0; i < size; i++)
    buf[i] = 0;
  return buf;
}

void CORBA::StringSequence::freebuf(char **buffer)
{
  delete [] buffer;
}

void CORBA::StringSequence::_allocate_buffer(CORBA::ULong length)
{
  char * *tmp = CORBA::StringSequence::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    char * *old = ACE_reinterpret_cast(char * *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      CORBA::StringSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::StringSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++)
  {
    CORBA::string_free(tmp[i]);
    tmp[i] = (char *)0;
  }
  

  CORBA::StringSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::StringSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::StringSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::StringSequence::length() const
{
  return this->_length;
}

void CORBA::StringSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::StringSequence::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
  char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);

  for(CORBA::ULong i = length1; i < length2; i++)
  {
    CORBA::string_free(tmp[i]);
    tmp[i] = (char *)0;
  }
}

char **CORBA::StringSequence::get_buffer(CORBA::Boolean orphan)
{
  char * *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::StringSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(char * *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(char * *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const char **CORBA::StringSequence::get_buffer() const
{
  return ACE_const_cast(const char * * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::StringSequence &o)
{
  ::CORBA::StringSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::StringSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_StringSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::StringSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_StringSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::StringSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_StringSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::StringSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::StringSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_StringSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_StringSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

TAO_SeqElem_String_Manager CORBA::StringSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  char * * tmp = ACE_reinterpret_cast(char * *, this->_buffer);
  return TAO_SeqElem_String_Manager(tmp + i,
                                    this->_release);
}

CORBA::StringSequence_var::StringSequence_var()
  : ptr_(0)
{}

CORBA::StringSequence_var::StringSequence_var(::CORBA::StringSequence *p)
 : ptr_(p)
{}

CORBA::StringSequence_var::StringSequence_var(const ::CORBA::StringSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::StringSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::StringSequence_var::~StringSequence_var()
{
  delete this->ptr_;
}

::CORBA::StringSequence_var &CORBA::StringSequence_var::operator=(::CORBA::StringSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::StringSequence_var &CORBA::StringSequence_var::operator=(const ::CORBA::StringSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::StringSequence (*p.ptr_);
  }
  return *this;
}

::CORBA::StringSequence *CORBA::StringSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::StringSequence *CORBA::StringSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::StringSequence_var::operator const ::CORBA::StringSequence &() const
{
  return *this->ptr_;
}

CORBA::StringSequence_var::operator ::CORBA::StringSequence &()
{
  return *this->ptr_;
}

CORBA::StringSequence_var::operator ::CORBA::StringSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::StringSequence &CORBA::StringSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::StringSequence &CORBA::StringSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::StringSequence *&CORBA::StringSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::StringSequence *CORBA::StringSequence_var::_retn()
{
  ::CORBA::StringSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::StringSequence *CORBA::StringSequence_var::ptr() const
{
  return this->ptr_;
}

TAO_SeqElem_String_Manager CORBA::StringSequence_var::operator[](CORBA::ULong i)
{
  return this->ptr_->operator[](i);
}

CORBA::StringSequence_out::StringSequence_out(::CORBA::StringSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::StringSequence_out::StringSequence_out(::CORBA::StringSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::StringSequence_out::StringSequence_out(const ::CORBA::StringSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::StringSequence_out &,r).ptr_)
{}

::CORBA::StringSequence_out &CORBA::StringSequence_out::operator=(const ::CORBA::StringSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::StringSequence_out &,r).ptr_;
  return *this;
}

::CORBA::StringSequence_out &CORBA::StringSequence_out::operator=(::CORBA::StringSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::StringSequence_out::operator ::CORBA::StringSequence *&()
{
  return this->ptr_;
}

::CORBA::StringSequence *&CORBA::StringSequence_out::ptr()
{
  return this->ptr_;
}

::CORBA::StringSequence *CORBA::StringSequence_out::operator->()
{
  return this->ptr_;
}

TAO_SeqElem_String_Manager CORBA::StringSequence_out::operator[](CORBA::ULong i)
{
  return this->ptr_->operator[](i);
}

static const CORBA::Long _oc_CORBA_OctetSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    28, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4f63), ACE_NTOHL(0x74657453), ACE_NTOHL(0x65717565), ACE_NTOHL(0x6e63653a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/OctetSequence:1.0 */,
    14, ACE_NTOHL(0x4f637465), ACE_NTOHL(0x74536571), ACE_NTOHL(0x75656e63), ACE_NTOHL(0x65000000) /* name = OctetSequence */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_octet,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_OctetSequence (CORBA::tk_alias, sizeof(_oc_CORBA_OctetSequence), (char *) &_oc_CORBA_OctetSequence, 0, sizeof(::CORBA::OctetSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_OctetSequence, &_tc_TAO_tc_CORBA_OctetSequence)
TAO_NAMESPACE_END

CORBA::OctetSequence::OctetSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::OctetSequence::OctetSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::OctetSequence::allocbuf(this->_maximum);
}

CORBA::OctetSequence::OctetSequence(CORBA::ULong max, CORBA::ULong length, CORBA::Octet *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::OctetSequence::OctetSequence(const ::CORBA::OctetSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Octet  *tmp1 = CORBA::OctetSequence::allocbuf(this->_maximum);

  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

CORBA::OctetSequence::~OctetSequence()
{
  this->_deallocate_buffer();
}

::CORBA::OctetSequence &CORBA::OctetSequence::operator=(const ::CORBA::OctetSequence &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);

      CORBA::OctetSequence::freebuf(tmp);
      this->_buffer = CORBA::OctetSequence::allocbuf(rhs._maximum);
    }

  }
  else
    this->_buffer = CORBA::OctetSequence::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Octet  *tmp1 = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Octet &CORBA::OctetSequence::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  return tmp[i];
}

const CORBA::Octet &CORBA::OctetSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * const tmp = ACE_reinterpret_cast(CORBA::Octet  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Octet *CORBA::OctetSequence::allocbuf(CORBA::ULong size)
{
  CORBA::Octet  *tmp;
  tmp = new CORBA::Octet [size];
  return tmp;
}

void CORBA::OctetSequence::freebuf(CORBA::Octet *buffer)
{
  delete [] buffer;
}

void CORBA::OctetSequence::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Octet  *tmp = CORBA::OctetSequence::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Octet  *old = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      CORBA::OctetSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::OctetSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);


  CORBA::OctetSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::OctetSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::OctetSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::OctetSequence::length() const
{
  return this->_length;
}

void CORBA::OctetSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::OctetSequence::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Octet *CORBA::OctetSequence::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Octet  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::OctetSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Octet *CORBA::OctetSequence::get_buffer() const
{
  return ACE_const_cast(const CORBA::Octet  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::OctetSequence &o)
{
  ::CORBA::OctetSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::OctetSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_OctetSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::OctetSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_OctetSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::OctetSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_OctetSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::OctetSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::OctetSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_OctetSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_OctetSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::OctetSequence_var::OctetSequence_var()
  : ptr_(0)
{}

CORBA::OctetSequence_var::OctetSequence_var(::CORBA::OctetSequence *p)
 : ptr_(p)
{}

CORBA::OctetSequence_var::OctetSequence_var(const ::CORBA::OctetSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::OctetSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::OctetSequence_var::~OctetSequence_var()
{
  delete this->ptr_;
}

::CORBA::OctetSequence_var &CORBA::OctetSequence_var::operator=(::CORBA::OctetSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::OctetSequence_var &CORBA::OctetSequence_var::operator=(const ::CORBA::OctetSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::OctetSequence (*p.ptr_);
  }
  return *this;
}

CORBA::Octet &CORBA::OctetSequence_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &CORBA::OctetSequence_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::OctetSequence *CORBA::OctetSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::OctetSequence_var::operator const ::CORBA::OctetSequence &() const
{
  return *this->ptr_;
}

CORBA::OctetSequence_var::operator ::CORBA::OctetSequence &()
{
  return *this->ptr_;
}

CORBA::OctetSequence_var::operator ::CORBA::OctetSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::OctetSequence &CORBA::OctetSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::OctetSequence &CORBA::OctetSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::OctetSequence *&CORBA::OctetSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::_retn()
{
  ::CORBA::OctetSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::ptr() const
{
  return this->ptr_;
}

CORBA::OctetSequence_out::OctetSequence_out(::CORBA::OctetSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::OctetSequence_out::OctetSequence_out(::CORBA::OctetSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::OctetSequence_out::OctetSequence_out(const ::CORBA::OctetSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::OctetSequence_out &,r).ptr_)
{}

::CORBA::OctetSequence_out &CORBA::OctetSequence_out::operator=(const ::CORBA::OctetSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::OctetSequence_out &,r).ptr_;
  return *this;
}

::CORBA::OctetSequence_out &CORBA::OctetSequence_out::operator=(::CORBA::OctetSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::OctetSequence_out::operator ::CORBA::OctetSequence *&()
{
  return this->ptr_;
}

::CORBA::OctetSequence *&CORBA::OctetSequence_out::ptr()
{
  return this->ptr_;
}

CORBA::Octet &CORBA::OctetSequence_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &CORBA::OctetSequence_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::OctetSequence *CORBA::OctetSequence_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_LongSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    27, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4c6f), ACE_NTOHL(0x6e675365), ACE_NTOHL(0x7175656e), ACE_NTOHL(0x63653a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:CORBA/LongSequence:1.0 */,
    13, ACE_NTOHL(0x4c6f6e67), ACE_NTOHL(0x53657175), ACE_NTOHL(0x656e6365), ACE_NTOHL(0x00000000) /* name = LongSequence */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_LongSequence (CORBA::tk_alias, sizeof(_oc_CORBA_LongSequence), (char *) &_oc_CORBA_LongSequence, 0, sizeof(::CORBA::LongSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_LongSequence, &_tc_TAO_tc_CORBA_LongSequence)
TAO_NAMESPACE_END

CORBA::LongSequence::LongSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::LongSequence::LongSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::LongSequence::allocbuf(this->_maximum);
}

CORBA::LongSequence::LongSequence(CORBA::ULong max, CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::LongSequence::LongSequence(const ::CORBA::LongSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = CORBA::LongSequence::allocbuf(this->_maximum);

  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

CORBA::LongSequence::~LongSequence()
{
  this->_deallocate_buffer();
}

::CORBA::LongSequence &CORBA::LongSequence::operator=(const ::CORBA::LongSequence &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);

      CORBA::LongSequence::freebuf(tmp);
      this->_buffer = CORBA::LongSequence::allocbuf(rhs._maximum);
    }

  }
  else
    this->_buffer = CORBA::LongSequence::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Long &CORBA::LongSequence::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &CORBA::LongSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *CORBA::LongSequence::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void CORBA::LongSequence::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void CORBA::LongSequence::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = CORBA::LongSequence::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      CORBA::LongSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::LongSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);


  CORBA::LongSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::LongSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::LongSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::LongSequence::length() const
{
  return this->_length;
}

void CORBA::LongSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::LongSequence::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Long *CORBA::LongSequence::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::LongSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *CORBA::LongSequence::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::LongSequence &o)
{
  ::CORBA::LongSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::LongSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_LongSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::LongSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_LongSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::LongSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_LongSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::LongSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::LongSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_LongSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_LongSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::LongSequence_var::LongSequence_var()
  : ptr_(0)
{}

CORBA::LongSequence_var::LongSequence_var(::CORBA::LongSequence *p)
 : ptr_(p)
{}

CORBA::LongSequence_var::LongSequence_var(const ::CORBA::LongSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::LongSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::LongSequence_var::~LongSequence_var()
{
  delete this->ptr_;
}

::CORBA::LongSequence_var &CORBA::LongSequence_var::operator=(::CORBA::LongSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::LongSequence_var &CORBA::LongSequence_var::operator=(const ::CORBA::LongSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::LongSequence (*p.ptr_);
  }
  return *this;
}

CORBA::Long &CORBA::LongSequence_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &CORBA::LongSequence_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::LongSequence *CORBA::LongSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::LongSequence *CORBA::LongSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::LongSequence_var::operator const ::CORBA::LongSequence &() const
{
  return *this->ptr_;
}

CORBA::LongSequence_var::operator ::CORBA::LongSequence &()
{
  return *this->ptr_;
}

CORBA::LongSequence_var::operator ::CORBA::LongSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::LongSequence &CORBA::LongSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::LongSequence &CORBA::LongSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::LongSequence *&CORBA::LongSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::LongSequence *CORBA::LongSequence_var::_retn()
{
  ::CORBA::LongSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::LongSequence *CORBA::LongSequence_var::ptr() const
{
  return this->ptr_;
}

CORBA::LongSequence_out::LongSequence_out(::CORBA::LongSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::LongSequence_out::LongSequence_out(::CORBA::LongSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::LongSequence_out::LongSequence_out(const ::CORBA::LongSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::LongSequence_out &,r).ptr_)
{}

::CORBA::LongSequence_out &CORBA::LongSequence_out::operator=(const ::CORBA::LongSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::LongSequence_out &,r).ptr_;
  return *this;
}

::CORBA::LongSequence_out &CORBA::LongSequence_out::operator=(::CORBA::LongSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::LongSequence_out::operator ::CORBA::LongSequence *&()
{
  return this->ptr_;
}

::CORBA::LongSequence *&CORBA::LongSequence_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &CORBA::LongSequence_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &CORBA::LongSequence_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::LongSequence *CORBA::LongSequence_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_ImplementationDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    32, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f496d), ACE_NTOHL(0x706c656d), ACE_NTOHL(0x656e7461), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x4465663a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/ImplementationDef:1.0 */,
    18, ACE_NTOHL(0x496d706c), ACE_NTOHL(0x656d656e), ACE_NTOHL(0x74617469), ACE_NTOHL(0x6f6e4465), ACE_NTOHL(0x66000000) /* name = ImplementationDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_ImplementationDef (CORBA::tk_objref, sizeof(_oc_CORBA_ImplementationDef), (char *) &_oc_CORBA_ImplementationDef, 0, sizeof(::CORBA::ImplementationDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_ImplementationDef, &_tc_TAO_tc_CORBA_ImplementationDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::ImplementationDef , ::CORBA::ImplementationDef_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::ImplementationDef , ::CORBA::ImplementationDef_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


::CORBA::ImplementationDef_ptr  (*CORBA::_TAO_collocation_ImplementationDef_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_duplicate(::CORBA::ImplementationDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return CORBA::ImplementationDef::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:CORBA/ImplementationDef:1.0", _env);
  if (_env.exception() != 0)
    return CORBA::ImplementationDef::_nil();
  if (is_a == 0)
    return CORBA::ImplementationDef::_nil();
  return CORBA::ImplementationDef::_unchecked_narrow(obj, _env);
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::ImplementationDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && CORBA::_TAO_collocation_ImplementationDef_Stub_Factory_function_pointer != 0)
    {
      ::CORBA::ImplementationDef_ptr  retv = CORBA::_TAO_collocation_ImplementationDef_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new ::CORBA::ImplementationDef (stub);
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_nil()
{
  return (::CORBA::ImplementationDef_ptr )NULL;
}

CORBA::Boolean CORBA::ImplementationDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::ImplementationDef::_interface_repository_id() const
{
  return "IDL:CORBA/ImplementationDef:1.0";
}

CORBA::ImplementationDef::ImplementationDef()
{}

CORBA::ImplementationDef::~ImplementationDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::ImplementationDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::ImplementationDef::_duplicate(o);
    a.replace (CORBA::_tc_ImplementationDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::ImplementationDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::ImplementationDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_ImplementationDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_ImplementationDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::ImplementationDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_ImplementationDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::ImplementationDef::ImplementationDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::ImplementationDef_var::ImplementationDef_var()
  : ptr_(CORBA::ImplementationDef::_nil())
{}

CORBA::ImplementationDef_var::ImplementationDef_var(::CORBA::ImplementationDef_ptr p)
  : ptr_(p)
{}

CORBA::ImplementationDef_var::ImplementationDef_var(const ::CORBA::ImplementationDef_var &a)
  : ptr_(CORBA::ImplementationDef::_duplicate(a.ptr()))
{}

CORBA::ImplementationDef_var::~ImplementationDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::ImplementationDef_var &CORBA::ImplementationDef_var::operator=(::CORBA::ImplementationDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::ImplementationDef_var &CORBA::ImplementationDef_var::operator=(const ::CORBA::ImplementationDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::ImplementationDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_var::operator const ::CORBA::ImplementationDef_ptr &() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_var::operator ::CORBA::ImplementationDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::in() const
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_var::inout()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ImplementationDef::_nil();
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::_retn()
{
  ::CORBA::ImplementationDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::ImplementationDef::_nil();
  return val;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_out::ImplementationDef_out(::CORBA::ImplementationDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::ImplementationDef::_nil();
}

CORBA::ImplementationDef_out::ImplementationDef_out(::CORBA::ImplementationDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ImplementationDef::_nil();
}

CORBA::ImplementationDef_out::ImplementationDef_out(const ::CORBA::ImplementationDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::ImplementationDef_out &,r).ptr_)
{}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(const ::CORBA::ImplementationDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::ImplementationDef_out &,r).ptr_;
  return *this;
}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(const ::CORBA::ImplementationDef_var &r)
{
  this->ptr_ = CORBA::ImplementationDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(::CORBA::ImplementationDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::ImplementationDef_out::operator ::CORBA::ImplementationDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_CreationImplDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    30, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4372), ACE_NTOHL(0x65617469), ACE_NTOHL(0x6f6e496d), ACE_NTOHL(0x706c4465), ACE_NTOHL(0x663a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:CORBA/CreationImplDef:1.0 */,
    16, ACE_NTOHL(0x43726561), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x496d706c), ACE_NTOHL(0x44656600) /* name = CreationImplDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_CreationImplDef (CORBA::tk_objref, sizeof(_oc_CORBA_CreationImplDef), (char *) &_oc_CORBA_CreationImplDef, 0, sizeof(::CORBA::CreationImplDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_CreationImplDef, &_tc_TAO_tc_CORBA_CreationImplDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::CreationImplDef , ::CORBA::CreationImplDef_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::CreationImplDef , ::CORBA::CreationImplDef_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


::CORBA::CreationImplDef_ptr  (*CORBA::_TAO_collocation_CreationImplDef_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_duplicate(::CORBA::CreationImplDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return CORBA::CreationImplDef::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:CORBA/CreationImplDef:1.0", _env);
  if (_env.exception() != 0)
    return CORBA::CreationImplDef::_nil();
  if (is_a == 0)
    return CORBA::CreationImplDef::_nil();
  return CORBA::CreationImplDef::_unchecked_narrow(obj, _env);
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::CreationImplDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && CORBA::_TAO_collocation_CreationImplDef_Stub_Factory_function_pointer != 0)
    {
      ::CORBA::CreationImplDef_ptr  retv = CORBA::_TAO_collocation_CreationImplDef_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new ::CORBA::CreationImplDef (stub);
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_nil()
{
  return (::CORBA::CreationImplDef_ptr )NULL;
}

CORBA::Boolean CORBA::CreationImplDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/CreationImplDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::CreationImplDef::_interface_repository_id() const
{
  return "IDL:CORBA/CreationImplDef:1.0";
}

CORBA::CreationImplDef::CreationImplDef()
{}

CORBA::CreationImplDef::~CreationImplDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::CreationImplDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::CreationImplDef::_duplicate(o);
    a.replace (CORBA::_tc_CreationImplDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::CreationImplDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::CreationImplDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_CreationImplDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_CreationImplDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::CreationImplDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_CreationImplDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::CreationImplDef::CreationImplDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::CreationImplDef_var::CreationImplDef_var()
  : ptr_(CORBA::CreationImplDef::_nil())
{}

CORBA::CreationImplDef_var::CreationImplDef_var(::CORBA::CreationImplDef_ptr p)
  : ptr_(p)
{}

CORBA::CreationImplDef_var::CreationImplDef_var(const ::CORBA::CreationImplDef_var &a)
  : ptr_(CORBA::CreationImplDef::_duplicate(a.ptr()))
{}

CORBA::CreationImplDef_var::~CreationImplDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::CreationImplDef_var &CORBA::CreationImplDef_var::operator=(::CORBA::CreationImplDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::CreationImplDef_var &CORBA::CreationImplDef_var::operator=(const ::CORBA::CreationImplDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::CreationImplDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_var::operator const ::CORBA::CreationImplDef_ptr &() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_var::operator ::CORBA::CreationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::in() const
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_var::inout()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::CreationImplDef::_nil();
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::_retn()
{
  ::CORBA::CreationImplDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::CreationImplDef::_nil();
  return val;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_out::CreationImplDef_out(::CORBA::CreationImplDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::CreationImplDef::_nil();
}

CORBA::CreationImplDef_out::CreationImplDef_out(::CORBA::CreationImplDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::CreationImplDef::_nil();
}

CORBA::CreationImplDef_out::CreationImplDef_out(const ::CORBA::CreationImplDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::CreationImplDef_out &,r).ptr_)
{}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(const ::CORBA::CreationImplDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::CreationImplDef_out &,r).ptr_;
  return *this;
}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(const ::CORBA::CreationImplDef_var &r)
{
  this->ptr_ = CORBA::CreationImplDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(::CORBA::CreationImplDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::CreationImplDef_out::operator ::CORBA::CreationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_Activator[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    24, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4163), ACE_NTOHL(0x74697661), ACE_NTOHL(0x746f723a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/Activator:1.0 */,
    10, ACE_NTOHL(0x41637469), ACE_NTOHL(0x7661746f), ACE_NTOHL(0x72000000) /* name = Activator */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_Activator (CORBA::tk_objref, sizeof(_oc_CORBA_Activator), (char *) &_oc_CORBA_Activator, 0, sizeof(::CORBA::Activator ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_Activator, &_tc_TAO_tc_CORBA_Activator)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::Activator , ::CORBA::Activator_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::Activator , ::CORBA::Activator_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


::CORBA::Activator_ptr  (*CORBA::_TAO_collocation_Activator_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


::CORBA::Activator_ptr CORBA::Activator::_duplicate(::CORBA::Activator_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::Activator_ptr CORBA::Activator::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return CORBA::Activator::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:CORBA/Activator:1.0", _env);
  if (_env.exception() != 0)
    return CORBA::Activator::_nil();
  if (is_a == 0)
    return CORBA::Activator::_nil();
  return CORBA::Activator::_unchecked_narrow(obj, _env);
}

::CORBA::Activator_ptr CORBA::Activator::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::Activator::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && CORBA::_TAO_collocation_Activator_Stub_Factory_function_pointer != 0)
    {
      ::CORBA::Activator_ptr  retv = CORBA::_TAO_collocation_Activator_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new ::CORBA::Activator (stub);
}

::CORBA::Activator_ptr CORBA::Activator::_nil()
{
  return (::CORBA::Activator_ptr )NULL;
}

CORBA::Boolean CORBA::Activator::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/Activator:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::Activator::_interface_repository_id() const
{
  return "IDL:CORBA/Activator:1.0";
}

CORBA::Activator::Activator()
{}

CORBA::Activator::~Activator()
{}

void operator<<=(CORBA::Any &a, ::CORBA::Activator_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::Activator::_duplicate(o);
    a.replace (CORBA::_tc_Activator, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::Activator_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::Activator::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_Activator, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_Activator, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::Activator::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_Activator, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::Activator::Activator(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::Activator_var::Activator_var()
  : ptr_(CORBA::Activator::_nil())
{}

CORBA::Activator_var::Activator_var(::CORBA::Activator_ptr p)
  : ptr_(p)
{}

CORBA::Activator_var::Activator_var(const ::CORBA::Activator_var &a)
  : ptr_(CORBA::Activator::_duplicate(a.ptr()))
{}

CORBA::Activator_var::~Activator_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::Activator_var &CORBA::Activator_var::operator=(::CORBA::Activator_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::Activator_var &CORBA::Activator_var::operator=(const ::CORBA::Activator_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::Activator::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::Activator_ptr CORBA::Activator_var::operator->() const
{
  return this->ptr_;
}

CORBA::Activator_var::operator const ::CORBA::Activator_ptr &() const
{
  return this->ptr_;
}

CORBA::Activator_var::operator ::CORBA::Activator_ptr &()
{
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_var::in() const
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_var::inout()
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::Activator::_nil();
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_var::_retn()
{
  ::CORBA::Activator_ptr  val = this->ptr_;
  this->ptr_ = CORBA::Activator::_nil();
  return val;
}

::CORBA::Activator_ptr CORBA::Activator_var::ptr() const
{
  return this->ptr_;
}

CORBA::Activator_out::Activator_out(::CORBA::Activator_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::Activator::_nil();
}

CORBA::Activator_out::Activator_out(::CORBA::Activator_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::Activator::_nil();
}

CORBA::Activator_out::Activator_out(const ::CORBA::Activator_out &r)
  : ptr_(ACE_const_cast(::CORBA::Activator_out &,r).ptr_)
{}

::CORBA::Activator_out &CORBA::Activator_out::operator=(const ::CORBA::Activator_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::Activator_out &,r).ptr_;
  return *this;
}

::CORBA::Activator_out &CORBA::Activator_out::operator=(const ::CORBA::Activator_var &r)
{
  this->ptr_ = CORBA::Activator::_duplicate(r.ptr());
  return *this;
}

::CORBA::Activator_out &CORBA::Activator_out::operator=(::CORBA::Activator_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::Activator_out::operator ::CORBA::Activator_ptr &()
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_out::ptr()
{
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_ActivationImplDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    32, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4163), ACE_NTOHL(0x74697661), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x496d706c), ACE_NTOHL(0x4465663a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/ActivationImplDef:1.0 */,
    18, ACE_NTOHL(0x41637469), ACE_NTOHL(0x76617469), ACE_NTOHL(0x6f6e496d), ACE_NTOHL(0x706c4465), ACE_NTOHL(0x66000000) /* name = ActivationImplDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_ActivationImplDef (CORBA::tk_objref, sizeof(_oc_CORBA_ActivationImplDef), (char *) &_oc_CORBA_ActivationImplDef, 0, sizeof(::CORBA::ActivationImplDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_ActivationImplDef, &_tc_TAO_tc_CORBA_ActivationImplDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::ActivationImplDef , ::CORBA::ActivationImplDef_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::ActivationImplDef , ::CORBA::ActivationImplDef_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


::CORBA::ActivationImplDef_ptr  (*CORBA::_TAO_collocation_ActivationImplDef_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_duplicate(::CORBA::ActivationImplDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return CORBA::ActivationImplDef::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:CORBA/ActivationImplDef:1.0", _env);
  if (_env.exception() != 0)
    return CORBA::ActivationImplDef::_nil();
  if (is_a == 0)
    return CORBA::ActivationImplDef::_nil();
  return CORBA::ActivationImplDef::_unchecked_narrow(obj, _env);
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::ActivationImplDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && CORBA::_TAO_collocation_ActivationImplDef_Stub_Factory_function_pointer != 0)
    {
      ::CORBA::ActivationImplDef_ptr  retv = CORBA::_TAO_collocation_ActivationImplDef_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new ::CORBA::ActivationImplDef (stub);
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_nil()
{
  return (::CORBA::ActivationImplDef_ptr )NULL;
}

CORBA::Boolean CORBA::ActivationImplDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ActivationImplDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::ActivationImplDef::_interface_repository_id() const
{
  return "IDL:CORBA/ActivationImplDef:1.0";
}

CORBA::ActivationImplDef::ActivationImplDef()
{}

CORBA::ActivationImplDef::~ActivationImplDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::ActivationImplDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::ActivationImplDef::_duplicate(o);
    a.replace (CORBA::_tc_ActivationImplDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::ActivationImplDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::ActivationImplDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_ActivationImplDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_ActivationImplDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::ActivationImplDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_ActivationImplDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::ActivationImplDef::ActivationImplDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var()
  : ptr_(CORBA::ActivationImplDef::_nil())
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var(::CORBA::ActivationImplDef_ptr p)
  : ptr_(p)
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var(const ::CORBA::ActivationImplDef_var &a)
  : ptr_(CORBA::ActivationImplDef::_duplicate(a.ptr()))
{}

CORBA::ActivationImplDef_var::~ActivationImplDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::ActivationImplDef_var &CORBA::ActivationImplDef_var::operator=(::CORBA::ActivationImplDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::ActivationImplDef_var &CORBA::ActivationImplDef_var::operator=(const ::CORBA::ActivationImplDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::ActivationImplDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_var::operator const ::CORBA::ActivationImplDef_ptr &() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_var::operator ::CORBA::ActivationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::in() const
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_var::inout()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ActivationImplDef::_nil();
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::_retn()
{
  ::CORBA::ActivationImplDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::ActivationImplDef::_nil();
  return val;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(::CORBA::ActivationImplDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::ActivationImplDef::_nil();
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(::CORBA::ActivationImplDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ActivationImplDef::_nil();
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(const ::CORBA::ActivationImplDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::ActivationImplDef_out &,r).ptr_)
{}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(const ::CORBA::ActivationImplDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::ActivationImplDef_out &,r).ptr_;
  return *this;
}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(const ::CORBA::ActivationImplDef_var &r)
{
  this->ptr_ = CORBA::ActivationImplDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(::CORBA::ActivationImplDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::ActivationImplDef_out::operator ::CORBA::ActivationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_out::operator->()
{
  return this->ptr_;
}
char *CORBA::ImplementationDef::interface_name(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort1);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t3_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t3_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t3_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t5_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort23);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t5_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t5_temp_string_len);
              flick_iiopxx_check_span(1 * _t5_temp_string_len, _flick_abort23);
              flick_iiopxx_decode_new_chunk(1 * _t5_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t5_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort23);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t5_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t5_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t5_temp_string_len);
              break;
              {
              _flick_abort23:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort27);
              break;
              {
              _flick_abort27:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort28);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort28:
                goto _flick_abort1;
              }
            }
          }
      }

    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t2_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort10);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t2_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t2_temp_string_len);
              flick_iiopxx_check_span(1 * _t2_temp_string_len, _flick_abort10);
              flick_iiopxx_decode_new_chunk(1 * _t2_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t2_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort10);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t2_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t2_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t2_temp_string_len);
              break;
              {
              _flick_abort10:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort14);
              break;
              {
              _flick_abort14:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort15);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort15:
                goto _flick_abort1;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort1);
  }
  return _return;
  {
  _flick_abort1:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort0);
  _flick_abort0:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ImplementationDef::interface_name(/* ::CORBA::ImplementationDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort30);
    }




    {
      flick_unsigned32_t _t7_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (interface_name), flick_unsigned32_t , _t7_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort30);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t7_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t7_temp_string_len, _flick_abort30);
      flick_iiopxx_encode_new_chunk(1 * _t7_temp_string_len);
      flick_cdr_encode_bcopy(0, (interface_name), 1 * _t7_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t7_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t7_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort30);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t9_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort30);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t9_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t9_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort48);
              break;
              {
              _flick_abort48:
                goto _flick_abort30;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort49);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort49:
                goto _flick_abort30;
              }
            }
          }
      }

    else
      {
        int _t8_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort30);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t8_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t8_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort41);
              break;
              {
              _flick_abort41:
                goto _flick_abort30;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort42);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort42:
                goto _flick_abort30;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort30);
  }
  return;
  {
  _flick_abort30:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort29);
  _flick_abort29:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::ImplementationDef::object_name(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort51);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort51);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort51);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t13_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort51);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t13_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t13_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t15_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort73);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t15_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t15_temp_string_len);
              flick_iiopxx_check_span(1 * _t15_temp_string_len, _flick_abort73);
              flick_iiopxx_decode_new_chunk(1 * _t15_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t15_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort73);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t15_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t15_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t15_temp_string_len);
              break;
              {
              _flick_abort73:
                goto _flick_abort51;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort77);
              break;
              {
              _flick_abort77:
                goto _flick_abort51;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort78);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort78:
                goto _flick_abort51;
              }
            }
          }
      }

    else
      {
        int _t10_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort51);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t10_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t10_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t12_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort60);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t12_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t12_temp_string_len);
              flick_iiopxx_check_span(1 * _t12_temp_string_len, _flick_abort60);
              flick_iiopxx_decode_new_chunk(1 * _t12_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t12_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort60);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t12_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t12_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t12_temp_string_len);
              break;
              {
              _flick_abort60:
                goto _flick_abort51;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort64);
              break;
              {
              _flick_abort64:
                goto _flick_abort51;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort65);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort65:
                goto _flick_abort51;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort51);
  }
  return _return;
  {
  _flick_abort51:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort50);
  _flick_abort50:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ImplementationDef::object_name(/* ::CORBA::ImplementationDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort80);
    }




    {
      flick_unsigned32_t _t17_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (object_name), flick_unsigned32_t , _t17_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort80);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t17_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t17_temp_string_len, _flick_abort80);
      flick_iiopxx_encode_new_chunk(1 * _t17_temp_string_len);
      flick_cdr_encode_bcopy(0, (object_name), 1 * _t17_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t17_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t17_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort80);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t19_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort80);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t19_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t19_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort98);
              break;
              {
              _flick_abort98:
                goto _flick_abort80;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort99);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort99:
                goto _flick_abort80;
              }
            }
          }
      }

    else
      {
        int _t18_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort80);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t18_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t18_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort91);
              break;
              {
              _flick_abort91:
                goto _flick_abort80;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort92);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort92:
                goto _flick_abort80;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort80);
  }
  return;
  {
  _flick_abort80:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort79);
  _flick_abort79:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::ReferenceData *CORBA::ImplementationDef::id(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::ReferenceData *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort101);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort101);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort101);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t21_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort101);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t21_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t21_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort120);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort120);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort120);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort120);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort120:
                goto _flick_abort101;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort123);
              break;
              {
              _flick_abort123:
                goto _flick_abort101;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort124);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort124:
                goto _flick_abort101;
              }
            }
          }
      }

    else
      {
        int _t20_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort101);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t20_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t20_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort109);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort109);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort109);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort109);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort109:
                goto _flick_abort101;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort112);
              break;
              {
              _flick_abort112:
                goto _flick_abort101;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort113);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort113:
                goto _flick_abort101;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort101);
  }
  return _return;
  {
  _flick_abort101:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort100);
  _flick_abort100:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ImplementationDef::id(/* ::CORBA::ImplementationDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort126);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort126);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort126);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort126);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t23_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort126);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t23_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t23_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort144);
              break;
              {
              _flick_abort144:
                goto _flick_abort126;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort145);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort145:
                goto _flick_abort126;
              }
            }
          }
      }

    else
      {
        int _t22_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort126);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t22_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t22_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort137);
              break;
              {
              _flick_abort137:
                goto _flick_abort126;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort138);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort138:
                goto _flick_abort126;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort126);
  }
  return;
  {
  _flick_abort126:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort125);
  _flick_abort125:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::CreationImplDef::path_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort147);
    }




    {
      flick_iiopxx_encode_new_glob(24, _flick_abort147);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 15, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'p', flick_char8_t );
      flick_cdr_encode_char8(10, 'a', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'h', flick_char8_t );
      flick_cdr_encode_char8(13, '_', flick_char8_t );
      flick_cdr_encode_char8(14, 'n', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'm', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort147);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t27_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort147);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t27_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t27_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t29_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort169);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t29_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t29_temp_string_len);
              flick_iiopxx_check_span(1 * _t29_temp_string_len, _flick_abort169);
              flick_iiopxx_decode_new_chunk(1 * _t29_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t29_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort169);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t29_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t29_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t29_temp_string_len);
              break;
              {
              _flick_abort169:
                goto _flick_abort147;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort173);
              break;
              {
              _flick_abort173:
                goto _flick_abort147;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort174);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort174:
                goto _flick_abort147;
              }
            }
          }
      }

    else
      {
        int _t24_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort147);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t24_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t24_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t26_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort156);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t26_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t26_temp_string_len);
              flick_iiopxx_check_span(1 * _t26_temp_string_len, _flick_abort156);
              flick_iiopxx_decode_new_chunk(1 * _t26_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t26_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort156);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t26_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t26_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t26_temp_string_len);
              break;
              {
              _flick_abort156:
                goto _flick_abort147;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort160);
              break;
              {
              _flick_abort160:
                goto _flick_abort147;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort161);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort161:
                goto _flick_abort147;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort147);
  }
  return _return;
  {
  _flick_abort147:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort146);
  _flick_abort146:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::path_name(/* ::CORBA::CreationImplDef *this, */ const char *path_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort176);
    }




    {
      flick_unsigned32_t _t31_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (path_name), flick_unsigned32_t , _t31_temp_string_len);

      flick_iiopxx_encode_new_glob(28, _flick_abort176);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 15, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'p', flick_char8_t );
      flick_cdr_encode_char8(10, 'a', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'h', flick_char8_t );
      flick_cdr_encode_char8(13, '_', flick_char8_t );
      flick_cdr_encode_char8(14, 'n', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'm', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(24, _t31_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
      flick_iiopxx_encode_new_glob(1 * _t31_temp_string_len, _flick_abort176);
      flick_iiopxx_encode_new_chunk(1 * _t31_temp_string_len);
      flick_cdr_encode_bcopy(0, (path_name), 1 * _t31_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t31_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t31_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort176);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t33_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort176);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t33_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t33_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort194);
              break;
              {
              _flick_abort194:
                goto _flick_abort176;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort195);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort195:
                goto _flick_abort176;
              }
            }
          }
      }

    else
      {
        int _t32_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort176);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t32_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t32_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort187);
              break;
              {
              _flick_abort187:
                goto _flick_abort176;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort188);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort188:
                goto _flick_abort176;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort176);
  }
  return;
  {
  _flick_abort176:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort175);
  _flick_abort175:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

enum ::CORBA::Policy CORBA::CreationImplDef::activation_policy(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  enum ::CORBA::Policy _return;


  _return = SHARED_SERVER;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort197);
    }




    {
      flick_iiopxx_encode_new_glob(32, _flick_abort197);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 23, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'i', flick_char8_t );
      flick_cdr_encode_char8(17, 'o', flick_char8_t );
      flick_cdr_encode_char8(18, 'n', flick_char8_t );
      flick_cdr_encode_char8(19, '_', flick_char8_t );
      flick_cdr_encode_char8(20, 'p', flick_char8_t );
      flick_cdr_encode_char8(21, 'o', flick_char8_t );
      flick_cdr_encode_char8(22, 'l', flick_char8_t );
      flick_cdr_encode_char8(23, 'i', flick_char8_t );
      flick_cdr_encode_char8(24, 'c', flick_char8_t );
      flick_cdr_encode_char8(25, 'y', flick_char8_t );
      flick_cdr_encode_char8(26, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(28, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort197);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t35_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort197);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t35_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t35_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort210);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return, enum ::CORBA::Policy );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort210:
                goto _flick_abort197;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort211);
              break;
              {
              _flick_abort211:
                goto _flick_abort197;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort212);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort212:
                goto _flick_abort197;
              }
            }
          }
      }

    else
      {
        int _t34_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort197);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t34_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t34_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort203);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return, enum ::CORBA::Policy );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort203:
                goto _flick_abort197;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort204);
              break;
              {
              _flick_abort204:
                goto _flick_abort197;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort205);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort205:
                goto _flick_abort197;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort197);
  }
  return _return;
  {
  _flick_abort197:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort196);
  _flick_abort196:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::activation_policy(/* ::CORBA::CreationImplDef *this, */ enum ::CORBA::Policy activation_policy, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort214);
    }




    {
      flick_iiopxx_encode_new_glob(36, _flick_abort214);
      flick_iiopxx_encode_new_chunk(36);
      flick_cdr_encode_unsigned32(0, 23, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'i', flick_char8_t );
      flick_cdr_encode_char8(17, 'o', flick_char8_t );
      flick_cdr_encode_char8(18, 'n', flick_char8_t );
      flick_cdr_encode_char8(19, '_', flick_char8_t );
      flick_cdr_encode_char8(20, 'p', flick_char8_t );
      flick_cdr_encode_char8(21, 'o', flick_char8_t );
      flick_cdr_encode_char8(22, 'l', flick_char8_t );
      flick_cdr_encode_char8(23, 'i', flick_char8_t );
      flick_cdr_encode_char8(24, 'c', flick_char8_t );
      flick_cdr_encode_char8(25, 'y', flick_char8_t );
      flick_cdr_encode_char8(26, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(28, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(32, activation_policy, enum ::CORBA::Policy );
      flick_iiopxx_encode_end_chunk(36);
      flick_iiopxx_encode_end_glob(36);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort214);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t37_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort214);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t37_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t37_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort228);
              break;
              {
              _flick_abort228:
                goto _flick_abort214;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort229);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort229:
                goto _flick_abort214;
              }
            }
          }
      }

    else
      {
        int _t36_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort214);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t36_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t36_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort221);
              break;
              {
              _flick_abort221:
                goto _flick_abort214;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort222);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort222:
                goto _flick_abort214;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort214);
  }
  return;
  {
  _flick_abort214:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort213);
  _flick_abort213:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::StringSequence *CORBA::CreationImplDef::args(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::StringSequence *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort231);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort231);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 's', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort231);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t51_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort231);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t51_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t51_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t61_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort319);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort319);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort319);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t61_array_iter = 0; _t61_array_iter < _return->_length; _t61_array_iter++)
                {
                  flick_unsigned32_t _t63_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort332);
                  flick_cdr_swap_decode_unsigned32(0, _t63_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t63_temp_string_len);
                  flick_iiopxx_check_span(1 * _t63_temp_string_len, _flick_abort332);
                  flick_iiopxx_decode_new_chunk(1 * _t63_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t63_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort332);
                    _return->_buffer[_t61_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_swap_decode_bcopy(0, _return->_buffer[_t61_array_iter], 1 * _t63_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t63_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t63_temp_string_len);
                  continue;
                  {
                  _flick_abort342:
                    _t61_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t61_array_iter]);
                  _flick_abort332:
                    if ((unsigned int )_t61_array_iter > 0)
                      goto _flick_abort342;
                    goto _flick_abort319;
                  }
                }
              break;
              {
              _flick_abort319:
                goto _flick_abort231;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort345);
              break;
              {
              _flick_abort345:
                goto _flick_abort231;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort346);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort346:
                goto _flick_abort231;
              }
            }
          }
      }

    else
      {
        int _t38_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort231);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t38_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t38_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t48_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort262);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort262);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort262);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t48_array_iter = 0; _t48_array_iter < _return->_length; _t48_array_iter++)
                {
                  flick_unsigned32_t _t50_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort275);
                  flick_cdr_decode_unsigned32(0, _t50_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t50_temp_string_len);
                  flick_iiopxx_check_span(1 * _t50_temp_string_len, _flick_abort275);
                  flick_iiopxx_decode_new_chunk(1 * _t50_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t50_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort275);
                    _return->_buffer[_t48_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_decode_bcopy(0, _return->_buffer[_t48_array_iter], 1 * _t50_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t50_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t50_temp_string_len);
                  continue;
                  {
                  _flick_abort285:
                    _t48_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t48_array_iter]);
                  _flick_abort275:
                    if ((unsigned int )_t48_array_iter > 0)
                      goto _flick_abort285;
                    goto _flick_abort262;
                  }
                }
              break;
              {
              _flick_abort262:
                goto _flick_abort231;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort288);
              break;
              {
              _flick_abort288:
                goto _flick_abort231;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort289);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort289:
                goto _flick_abort231;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort231);
  }
  return _return;
  {
  _flick_abort231:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort230);
  _flick_abort230:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::args(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::StringSequence &args, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort348);
    }




    {
      CORBA::ULong _t73_array_iter;

      flick_iiopxx_encode_new_glob(24, _flick_abort348);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 's', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, args._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      for (_t73_array_iter = 0; _t73_array_iter < args._length; _t73_array_iter++)
        {
          flick_unsigned32_t _t75_temp_string_len;

          flick_cdr_stringlen(CORBA::Char *, (args._buffer[_t73_array_iter]), flick_unsigned32_t , _t75_temp_string_len);

          flick_iiopxx_encode_new_glob(7, _flick_abort374);
          flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
          flick_cdr_encode_unsigned32(0, _t75_temp_string_len, flick_unsigned32_t );
          flick_iiopxx_encode_end_chunk(4);
          flick_iiopxx_encode_end_glob(7);
          flick_iiopxx_encode_new_glob(1 * _t75_temp_string_len, _flick_abort374);
          flick_iiopxx_encode_new_chunk(1 * _t75_temp_string_len);
          flick_cdr_encode_bcopy(0, (args._buffer[_t73_array_iter]), 1 * _t75_temp_string_len);
          flick_iiopxx_encode_end_chunk(1 * _t75_temp_string_len);
          flick_iiopxx_encode_end_glob(1 * _t75_temp_string_len);
          continue;
          {
          _flick_abort374:
            goto _flick_abort348;
          }
        }
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort348);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t77_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort348);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t77_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t77_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort392);
              break;
              {
              _flick_abort392:
                goto _flick_abort348;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort393);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort393:
                goto _flick_abort348;
              }
            }
          }
      }

    else
      {
        int _t76_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort348);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t76_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t76_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort385);
              break;
              {
              _flick_abort385:
                goto _flick_abort348;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort386);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort386:
                goto _flick_abort348;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort348);
  }
  return;
  {
  _flick_abort348:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort347);
  _flick_abort347:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::StringSequence *CORBA::CreationImplDef::env(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::StringSequence *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort395);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort395);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'e', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'v', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort395);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t91_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort395);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t91_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t91_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t101_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort483);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort483);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort483);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t101_array_iter = 0; _t101_array_iter < _return->_length; _t101_array_iter++)
                {
                  flick_unsigned32_t _t103_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort496);
                  flick_cdr_swap_decode_unsigned32(0, _t103_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t103_temp_string_len);
                  flick_iiopxx_check_span(1 * _t103_temp_string_len, _flick_abort496);
                  flick_iiopxx_decode_new_chunk(1 * _t103_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t103_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort496);
                    _return->_buffer[_t101_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_swap_decode_bcopy(0, _return->_buffer[_t101_array_iter], 1 * _t103_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t103_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t103_temp_string_len);
                  continue;
                  {
                  _flick_abort506:
                    _t101_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t101_array_iter]);
                  _flick_abort496:
                    if ((unsigned int )_t101_array_iter > 0)
                      goto _flick_abort506;
                    goto _flick_abort483;
                  }
                }
              break;
              {
              _flick_abort483:
                goto _flick_abort395;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort509);
              break;
              {
              _flick_abort509:
                goto _flick_abort395;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort510);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort510:
                goto _flick_abort395;
              }
            }
          }
      }

    else
      {
        int _t78_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort395);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t78_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t78_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t88_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort426);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort426);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort426);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t88_array_iter = 0; _t88_array_iter < _return->_length; _t88_array_iter++)
                {
                  flick_unsigned32_t _t90_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort439);
                  flick_cdr_decode_unsigned32(0, _t90_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t90_temp_string_len);
                  flick_iiopxx_check_span(1 * _t90_temp_string_len, _flick_abort439);
                  flick_iiopxx_decode_new_chunk(1 * _t90_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t90_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort439);
                    _return->_buffer[_t88_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_decode_bcopy(0, _return->_buffer[_t88_array_iter], 1 * _t90_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t90_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t90_temp_string_len);
                  continue;
                  {
                  _flick_abort449:
                    _t88_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t88_array_iter]);
                  _flick_abort439:
                    if ((unsigned int )_t88_array_iter > 0)
                      goto _flick_abort449;
                    goto _flick_abort426;
                  }
                }
              break;
              {
              _flick_abort426:
                goto _flick_abort395;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort452);
              break;
              {
              _flick_abort452:
                goto _flick_abort395;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort453);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort453:
                goto _flick_abort395;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort395);
  }
  return _return;
  {
  _flick_abort395:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort394);
  _flick_abort394:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::env(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::StringSequence &env, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort512);
    }




    {
      CORBA::ULong _t113_array_iter;

      flick_iiopxx_encode_new_glob(24, _flick_abort512);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'e', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'v', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, env._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      for (_t113_array_iter = 0; _t113_array_iter < env._length; _t113_array_iter++)
        {
          flick_unsigned32_t _t115_temp_string_len;

          flick_cdr_stringlen(CORBA::Char *, (env._buffer[_t113_array_iter]), flick_unsigned32_t , _t115_temp_string_len);

          flick_iiopxx_encode_new_glob(7, _flick_abort538);
          flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
          flick_cdr_encode_unsigned32(0, _t115_temp_string_len, flick_unsigned32_t );
          flick_iiopxx_encode_end_chunk(4);
          flick_iiopxx_encode_end_glob(7);
          flick_iiopxx_encode_new_glob(1 * _t115_temp_string_len, _flick_abort538);
          flick_iiopxx_encode_new_chunk(1 * _t115_temp_string_len);
          flick_cdr_encode_bcopy(0, (env._buffer[_t113_array_iter]), 1 * _t115_temp_string_len);
          flick_iiopxx_encode_end_chunk(1 * _t115_temp_string_len);
          flick_iiopxx_encode_end_glob(1 * _t115_temp_string_len);
          continue;
          {
          _flick_abort538:
            goto _flick_abort512;
          }
        }
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort512);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t117_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort512);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t117_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t117_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort556);
              break;
              {
              _flick_abort556:
                goto _flick_abort512;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort557);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort557:
                goto _flick_abort512;
              }
            }
          }
      }

    else
      {
        int _t116_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort512);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t116_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t116_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort549);
              break;
              {
              _flick_abort549:
                goto _flick_abort512;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort550);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort550:
                goto _flick_abort512;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort512);
  }
  return;
  {
  _flick_abort512:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort511);
  _flick_abort511:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::CreationImplDef::interface_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort559);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort559);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort559);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t121_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort559);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t121_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t121_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t123_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort581);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t123_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t123_temp_string_len);
              flick_iiopxx_check_span(1 * _t123_temp_string_len, _flick_abort581);
              flick_iiopxx_decode_new_chunk(1 * _t123_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t123_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort581);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t123_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t123_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t123_temp_string_len);
              break;
              {
              _flick_abort581:
                goto _flick_abort559;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort585);
              break;
              {
              _flick_abort585:
                goto _flick_abort559;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort586);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort586:
                goto _flick_abort559;
              }
            }
          }
      }

    else
      {
        int _t118_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort559);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t118_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t118_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t120_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort568);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t120_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t120_temp_string_len);
              flick_iiopxx_check_span(1 * _t120_temp_string_len, _flick_abort568);
              flick_iiopxx_decode_new_chunk(1 * _t120_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t120_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort568);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t120_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t120_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t120_temp_string_len);
              break;
              {
              _flick_abort568:
                goto _flick_abort559;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort572);
              break;
              {
              _flick_abort572:
                goto _flick_abort559;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort573);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort573:
                goto _flick_abort559;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort559);
  }
  return _return;
  {
  _flick_abort559:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort558);
  _flick_abort558:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::interface_name(/* ::CORBA::CreationImplDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort588);
    }




    {
      flick_unsigned32_t _t125_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (interface_name), flick_unsigned32_t , _t125_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort588);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t125_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t125_temp_string_len, _flick_abort588);
      flick_iiopxx_encode_new_chunk(1 * _t125_temp_string_len);
      flick_cdr_encode_bcopy(0, (interface_name), 1 * _t125_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t125_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t125_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort588);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t127_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort588);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t127_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t127_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort606);
              break;
              {
              _flick_abort606:
                goto _flick_abort588;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort607);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort607:
                goto _flick_abort588;
              }
            }
          }
      }

    else
      {
        int _t126_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort588);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t126_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t126_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort599);
              break;
              {
              _flick_abort599:
                goto _flick_abort588;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort600);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort600:
                goto _flick_abort588;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort588);
  }
  return;
  {
  _flick_abort588:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort587);
  _flick_abort587:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::CreationImplDef::object_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort609);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort609);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort609);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t131_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort609);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t131_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t131_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t133_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort631);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t133_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t133_temp_string_len);
              flick_iiopxx_check_span(1 * _t133_temp_string_len, _flick_abort631);
              flick_iiopxx_decode_new_chunk(1 * _t133_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t133_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort631);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t133_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t133_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t133_temp_string_len);
              break;
              {
              _flick_abort631:
                goto _flick_abort609;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort635);
              break;
              {
              _flick_abort635:
                goto _flick_abort609;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort636);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort636:
                goto _flick_abort609;
              }
            }
          }
      }

    else
      {
        int _t128_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort609);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t128_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t128_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t130_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort618);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t130_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t130_temp_string_len);
              flick_iiopxx_check_span(1 * _t130_temp_string_len, _flick_abort618);
              flick_iiopxx_decode_new_chunk(1 * _t130_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t130_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort618);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t130_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t130_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t130_temp_string_len);
              break;
              {
              _flick_abort618:
                goto _flick_abort609;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort622);
              break;
              {
              _flick_abort622:
                goto _flick_abort609;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort623);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort623:
                goto _flick_abort609;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort609);
  }
  return _return;
  {
  _flick_abort609:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort608);
  _flick_abort608:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::object_name(/* ::CORBA::CreationImplDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort638);
    }




    {
      flick_unsigned32_t _t135_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (object_name), flick_unsigned32_t , _t135_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort638);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t135_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t135_temp_string_len, _flick_abort638);
      flick_iiopxx_encode_new_chunk(1 * _t135_temp_string_len);
      flick_cdr_encode_bcopy(0, (object_name), 1 * _t135_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t135_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t135_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort638);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t137_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort638);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t137_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t137_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort656);
              break;
              {
              _flick_abort656:
                goto _flick_abort638;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort657);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort657:
                goto _flick_abort638;
              }
            }
          }
      }

    else
      {
        int _t136_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort638);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t136_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t136_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort649);
              break;
              {
              _flick_abort649:
                goto _flick_abort638;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort650);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort650:
                goto _flick_abort638;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort638);
  }
  return;
  {
  _flick_abort638:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort637);
  _flick_abort637:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::ReferenceData *CORBA::CreationImplDef::id(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::ReferenceData *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort659);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort659);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort659);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t139_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort659);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t139_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t139_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort678);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort678);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort678);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort678);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort678:
                goto _flick_abort659;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort681);
              break;
              {
              _flick_abort681:
                goto _flick_abort659;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort682);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort682:
                goto _flick_abort659;
              }
            }
          }
      }

    else
      {
        int _t138_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort659);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t138_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t138_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort667);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort667);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort667);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort667);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort667:
                goto _flick_abort659;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort670);
              break;
              {
              _flick_abort670:
                goto _flick_abort659;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort671);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort671:
                goto _flick_abort659;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort659);
  }
  return _return;
  {
  _flick_abort659:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort658);
  _flick_abort658:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::CreationImplDef::id(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort684);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort684);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort684);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort684);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t141_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort684);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t141_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t141_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort702);
              break;
              {
              _flick_abort702:
                goto _flick_abort684;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort703);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort703:
                goto _flick_abort684;
              }
            }
          }
      }

    else
      {
        int _t140_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort684);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t140_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t140_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort695);
              break;
              {
              _flick_abort695:
                goto _flick_abort684;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort696);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort696:
                goto _flick_abort684;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort684);
  }
  return;
  {
  _flick_abort684:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort683);
  _flick_abort683:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::Object_ptr CORBA::Activator::activate(/* ::CORBA::Activator *this, */ ::CORBA::ImplementationDef_ptr impl, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::Object_ptr _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort705);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort705);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'a', flick_char8_t );
      flick_cdr_encode_char8(5, 'c', flick_char8_t );
      flick_cdr_encode_char8(6, 't', flick_char8_t );
      flick_cdr_encode_char8(7, 'i', flick_char8_t );
      flick_cdr_encode_char8(8, 'v', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 't', flick_char8_t );
      flick_cdr_encode_char8(11, 'e', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_cdrxx_encode_IOR(iiopxx, impl, 0, CORBA::ImplementationDef , _flick_abort705);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort705);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t143_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort705);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t143_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t143_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_swapxx_decode_IOR(iiopxx, _return, 1, CORBA::Object , _flick_abort718);
              break;
              {
              _flick_abort718:
                goto _flick_abort705;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort719);
              break;
              {
              _flick_abort719:
                goto _flick_abort705;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort720);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort720:
                goto _flick_abort705;
              }
            }
          }
      }

    else
      {
        int _t142_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort705);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t142_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t142_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdrxx_decode_IOR(iiopxx, _return, 1, CORBA::Object , _flick_abort711);
              break;
              {
              _flick_abort711:
                goto _flick_abort705;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort712);
              break;
              {
              _flick_abort712:
                goto _flick_abort705;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort713);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort713:
                goto _flick_abort705;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort705);
  }
  return _return;
  {
  _flick_abort705:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort704);
  _flick_abort704:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::Activator::deactivate(/* ::CORBA::Activator *this, */ ::CORBA::Object_ptr obj, ::CORBA::ImplementationDef_ptr impl, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort722);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort722);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 11, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'd', flick_char8_t );
      flick_cdr_encode_char8(5, 'e', flick_char8_t );
      flick_cdr_encode_char8(6, 'a', flick_char8_t );
      flick_cdr_encode_char8(7, 'c', flick_char8_t );
      flick_cdr_encode_char8(8, 't', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'v', flick_char8_t );
      flick_cdr_encode_char8(11, 'a', flick_char8_t );
      flick_cdr_encode_char8(12, 't', flick_char8_t );
      flick_cdr_encode_char8(13, 'e', flick_char8_t );
      flick_cdr_encode_char8(14, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_cdrxx_encode_IOR(iiopxx, obj, 0, CORBA::Object , _flick_abort722);
      flick_cdrxx_encode_IOR(iiopxx, impl, 0, CORBA::ImplementationDef , _flick_abort722);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort722);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t145_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort722);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t145_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t145_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort736);
              break;
              {
              _flick_abort736:
                goto _flick_abort722;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort737);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort737:
                goto _flick_abort722;
              }
            }
          }
      }

    else
      {
        int _t144_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort722);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t144_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t144_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort729);
              break;
              {
              _flick_abort729:
                goto _flick_abort722;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort730);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort730:
                goto _flick_abort722;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort722);
  }
  return;
  {
  _flick_abort722:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort721);
  _flick_abort721:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::Activator_ptr CORBA::ActivationImplDef::activator_obj(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::Activator_ptr _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort739);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort739);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 19, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'o', flick_char8_t );
      flick_cdr_encode_char8(17, 'r', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'o', flick_char8_t );
      flick_cdr_encode_char8(20, 'b', flick_char8_t );
      flick_cdr_encode_char8(21, 'j', flick_char8_t );
      flick_cdr_encode_char8(22, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort739);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t147_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort739);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t147_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t147_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_swapxx_decode_IOR(iiopxx, _return, 1, CORBA::Activator , _flick_abort752);
              break;
              {
              _flick_abort752:
                goto _flick_abort739;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort753);
              break;
              {
              _flick_abort753:
                goto _flick_abort739;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort754);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort754:
                goto _flick_abort739;
              }
            }
          }
      }

    else
      {
        int _t146_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort739);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t146_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t146_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdrxx_decode_IOR(iiopxx, _return, 1, CORBA::Activator , _flick_abort745);
              break;
              {
              _flick_abort745:
                goto _flick_abort739;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort746);
              break;
              {
              _flick_abort746:
                goto _flick_abort739;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort747);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort747:
                goto _flick_abort739;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort739);
  }
  return _return;
  {
  _flick_abort739:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort738);
  _flick_abort738:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ActivationImplDef::activator_obj(/* ::CORBA::ActivationImplDef *this, */ ::CORBA::Activator_ptr activator_obj, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort756);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort756);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 19, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'o', flick_char8_t );
      flick_cdr_encode_char8(17, 'r', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'o', flick_char8_t );
      flick_cdr_encode_char8(20, 'b', flick_char8_t );
      flick_cdr_encode_char8(21, 'j', flick_char8_t );
      flick_cdr_encode_char8(22, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
      flick_cdrxx_encode_IOR(iiopxx, activator_obj, 0, CORBA::Activator , _flick_abort756);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort756);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t149_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort756);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t149_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t149_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort770);
              break;
              {
              _flick_abort770:
                goto _flick_abort756;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort771);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort771:
                goto _flick_abort756;
              }
            }
          }
      }

    else
      {
        int _t148_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort756);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t148_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t148_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort763);
              break;
              {
              _flick_abort763:
                goto _flick_abort756;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort764);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort764:
                goto _flick_abort756;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort756);
  }
  return;
  {
  _flick_abort756:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort755);
  _flick_abort755:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::ActivationImplDef::interface_name(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort773);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort773);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort773);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t153_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort773);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t153_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t153_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t155_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort795);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t155_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t155_temp_string_len);
              flick_iiopxx_check_span(1 * _t155_temp_string_len, _flick_abort795);
              flick_iiopxx_decode_new_chunk(1 * _t155_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t155_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort795);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t155_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t155_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t155_temp_string_len);
              break;
              {
              _flick_abort795:
                goto _flick_abort773;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort799);
              break;
              {
              _flick_abort799:
                goto _flick_abort773;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort800);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort800:
                goto _flick_abort773;
              }
            }
          }
      }

    else
      {
        int _t150_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort773);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t150_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t150_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t152_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort782);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t152_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t152_temp_string_len);
              flick_iiopxx_check_span(1 * _t152_temp_string_len, _flick_abort782);
              flick_iiopxx_decode_new_chunk(1 * _t152_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t152_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort782);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t152_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t152_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t152_temp_string_len);
              break;
              {
              _flick_abort782:
                goto _flick_abort773;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort786);
              break;
              {
              _flick_abort786:
                goto _flick_abort773;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort787);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort787:
                goto _flick_abort773;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort773);
  }
  return _return;
  {
  _flick_abort773:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort772);
  _flick_abort772:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ActivationImplDef::interface_name(/* ::CORBA::ActivationImplDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort802);
    }




    {
      flick_unsigned32_t _t157_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (interface_name), flick_unsigned32_t , _t157_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort802);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t157_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t157_temp_string_len, _flick_abort802);
      flick_iiopxx_encode_new_chunk(1 * _t157_temp_string_len);
      flick_cdr_encode_bcopy(0, (interface_name), 1 * _t157_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t157_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t157_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort802);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t159_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort802);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t159_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t159_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort820);
              break;
              {
              _flick_abort820:
                goto _flick_abort802;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort821);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort821:
                goto _flick_abort802;
              }
            }
          }
      }

    else
      {
        int _t158_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort802);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t158_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t158_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort813);
              break;
              {
              _flick_abort813:
                goto _flick_abort802;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort814);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort814:
                goto _flick_abort802;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort802);
  }
  return;
  {
  _flick_abort802:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort801);
  _flick_abort801:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

char *CORBA::ActivationImplDef::object_name(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort823);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort823);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort823);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t163_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort823);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t163_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t163_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t165_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort845);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t165_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t165_temp_string_len);
              flick_iiopxx_check_span(1 * _t165_temp_string_len, _flick_abort845);
              flick_iiopxx_decode_new_chunk(1 * _t165_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t165_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort845);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t165_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t165_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t165_temp_string_len);
              break;
              {
              _flick_abort845:
                goto _flick_abort823;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort849);
              break;
              {
              _flick_abort849:
                goto _flick_abort823;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort850);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort850:
                goto _flick_abort823;
              }
            }
          }
      }

    else
      {
        int _t160_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort823);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t160_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t160_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t162_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort832);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t162_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t162_temp_string_len);
              flick_iiopxx_check_span(1 * _t162_temp_string_len, _flick_abort832);
              flick_iiopxx_decode_new_chunk(1 * _t162_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t162_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort832);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t162_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t162_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t162_temp_string_len);
              break;
              {
              _flick_abort832:
                goto _flick_abort823;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort836);
              break;
              {
              _flick_abort836:
                goto _flick_abort823;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort837);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort837:
                goto _flick_abort823;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort823);
  }
  return _return;
  {
  _flick_abort823:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort822);
  _flick_abort822:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ActivationImplDef::object_name(/* ::CORBA::ActivationImplDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort852);
    }




    {
      flick_unsigned32_t _t167_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (object_name), flick_unsigned32_t , _t167_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort852);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t167_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t167_temp_string_len, _flick_abort852);
      flick_iiopxx_encode_new_chunk(1 * _t167_temp_string_len);
      flick_cdr_encode_bcopy(0, (object_name), 1 * _t167_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t167_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t167_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort852);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t169_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort852);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t169_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t169_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort870);
              break;
              {
              _flick_abort870:
                goto _flick_abort852;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort871);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort871:
                goto _flick_abort852;
              }
            }
          }
      }

    else
      {
        int _t168_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort852);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t168_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t168_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort863);
              break;
              {
              _flick_abort863:
                goto _flick_abort852;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort864);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort864:
                goto _flick_abort852;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort852);
  }
  return;
  {
  _flick_abort852:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort851);
  _flick_abort851:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

::CORBA::ReferenceData *CORBA::ActivationImplDef::id(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  ::CORBA::ReferenceData *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort873);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort873);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort873);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t171_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort873);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t171_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t171_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort892);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort892);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort892);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort892);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort892:
                goto _flick_abort873;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort895);
              break;
              {
              _flick_abort895:
                goto _flick_abort873;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort896);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort896:
                goto _flick_abort873;
              }
            }
          }
      }

    else
      {
        int _t170_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort873);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t170_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t170_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort881);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort881);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort881);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort881);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort881:
                goto _flick_abort873;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort884);
              break;
              {
              _flick_abort884:
                goto _flick_abort873;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort885);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort885:
                goto _flick_abort873;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort873);
  }
  return _return;
  {
  _flick_abort873:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort872);
  _flick_abort872:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void CORBA::ActivationImplDef::id(/* ::CORBA::ActivationImplDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort898);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort898);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort898);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort898);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t173_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort898);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t173_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t173_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort916);
              break;
              {
              _flick_abort916:
                goto _flick_abort898;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort917);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort917:
                goto _flick_abort898;
              }
            }
          }
      }

    else
      {
        int _t172_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort898);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t172_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t172_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort909);
              break;
              {
              _flick_abort909:
                goto _flick_abort898;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort910);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort910:
                goto _flick_abort898;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort898);
  }
  return;
  {
  _flick_abort898:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort897);
  _flick_abort897:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

